﻿package
{
	import flash.display.Sprite;
	import flash.filters.BlurFilter;
	import flash.filters.DropShadowFilter;
	import flash.events.Event;
	import flash.text.TextField;
	import com.gskinner.motion.GTween;
	import fl.motion.easing.*;

	public class ImageStackContainer extends Sprite
	{
		private var items:Array = new Array();
		private var titles:Array = new Array();
		
		private var imageAmount:int = 0;
		
		private var canMove:Boolean = true;
		
		private var titletxt:TextField;
		
		
		/**
		 * constructor
		 */
		public function ImageStackContainer(_title:TextField)
		{
			titletxt = _title;
			
			trace("ImageStackContainer* instantiated");
		}
		
		
		/**
		 * adds an image to the stack
		 */
		public function addImageToStack(_image:StackItem, _title:String):void
		{
			// push new items on to the stack
			items.push(_image);
			titles.push(_title);
			
			imageAmount = items.length-1;
		}
		
		
		/**
		 * layout the stack once all the images/items have been added
		 */
		public function initialStackLayout():void
		{
			// reverse
			items = items.reverse();
			titles = titles.reverse();
			
			for(var i:Number = imageAmount; i > -1; i--)
			{
				var stackItem:StackItem = items[i];
				
				stackItem.rotationY = 17;
				stackItem.x = 310 + (i * 80);
				stackItem.y = 150 - (i * 25);
				stackItem.z = i * 100;
				
				var blurFilter:BlurFilter = new BlurFilter(i * 2, i * 2, 1);
				var shadowFilter:DropShadowFilter = new DropShadowFilter(2, 45, 0x000000, 0.5, 3, 3);
				
				var itemFilters:Array = new Array();
				itemFilters.push(shadowFilter);
				
				stackItem.filters = itemFilters; 
				
				this.addChild(stackItem);
				
				stackItem = null;
			}
			
			titletxt.text = titles[0];
		}
		
		
		
		/**
		 * displays the next image in the stack and pops the first to the last position
		 */
		public function nextImage():void
		{
			if(canMove)
			{
				// re-arrange the arrays for depth sorting purposes
				var tmpItem = items[0];
				var tmpTitle = titles[0];
				
				items.push(tmpItem);
				titles.push(tmpTitle);
				
				items.shift();
				titles.shift();
				
				// tween the first image out
				var item:StackItem = (tmpItem as StackItem);
				
				var tween:GTween = new GTween(item, 0.5, {x:item.x-150, y:item.y+50, z:item.z-200, alpha:0}, {ease:Sine.easeInOut});
				tween.addEventListener(Event.COMPLETE, readjustOnFlyForNext); 
				
				// now tween each shape to the correct position
				for(var i:Number = imageAmount-1; i > -1; i--)
				{
					var item:StackItem = items[i];
					
					new GTween(item, 0.5, {x:340 + (i * 80), y:130 - (i * 25), z:i * 100, alpha:1}, {ease:Sine.easeInOut});
				}
				
				canMove = false;
			}
			
			// adjusts, tweens each item to new positions
			function readjustOnFlyForNext (e:Event):void
			{
				// sort the display list, and reset 
				for(var i:Number = imageAmount; i > -1; i--)
				{
					var stackItem:StackItem = items[i];
					
					addChild(stackItem);
				}
	
				// copy the new text data			
				titletxt.text = titles[0];
				
				// allow the buttons to work again
				canMove = true;
			}
		}
		
		
		
		/**
		 * displays the previous image in the stack and pops the first to the second position
		 */
		public function prevImage():void
		{
			if(canMove)
			{
				// re-arrange the arrays for depth sorting purposes
				var tmpItem = items[imageAmount];
				var tmpTitle = titles[imageAmount];
				
				items.splice(0, 0, tmpItem);
				titles.splice(0, 0, tmpTitle);
				
				items.pop()
				titles.pop();
				
				// tween the first image out
				var item:StackItem = (tmpItem as StackItem);
				var firstItem:StackItem = (items[1] as StackItem);
				
				item.x = firstItem.x-150;
				item.y = firstItem.y+50;
				item.z = firstItem.z-200;
				item.alpha = 0;
				
				var tween:GTween = new GTween(item, 0.5, {x:firstItem.x, y:firstItem.y, z:firstItem.z, alpha:1}, {ease:Sine.easeInOut});
				tween.addEventListener(Event.COMPLETE, readjustOnFlyForPrev);
				
				
				// now tween each shape to the correct position
				for(var i:Number = imageAmount; i > 0; i--)
				{
					var item:StackItem = items[i];
				
					new GTween(item, 0.5, {x:340 + (i * 80), y:130 - (i * 25), z:i * 100, alpha:1}, {ease:Sine.easeInOut});
				}
				
				// sort the display list, and reset 
				for(var i:Number = imageAmount; i > -1; i--)
				{
					var stackItem:StackItem = items[i];
					
					addChild(stackItem);
				}
				
				canMove = false;
			}
			
			// adjusts, tweens each item to new positions
			function readjustOnFlyForPrev (e:Event):void
			{
				// copy the new text data			
				titletxt.text = titles[0];
				
				// allow the buttons to work again
				canMove = true;
			}
		}
	}
}